svg Package
===========

:mod:`svg` Package
------------------

.. automodule:: svg.__init__
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    svg.charts

